@@ -1,5 +1,5 @@
 package TestsFor::FailChild;
-use Test::Class::Moose extends => 'Fail';
+use Test::Class::Moose extends => 'TestsFor::Fail';
 
 sub test_a_good {
     ok 1;
